pub struct CountLines { /* private fields */ }Implementations
Sourceimpl CountLines
impl CountLines
pub fn new( quote_char: Option<u8>, eol_char: u8, comment_prefix: Option<CommentPrefix>, ) -> CountLines
Sourcepub fn analyze_chunk(&self, bytes: &[u8]) -> [LineStats; 2]
pub fn analyze_chunk(&self, bytes: &[u8]) -> [LineStats; 2]
Analyzes a chunk of CSV data.
Returns (newline_count, last_newline_offset, end_inside_string) twice, the first is assuming the start of the chunk is not inside a string, the second assuming the start is inside a string.
If comment_prefix is not None the start of bytes must be at the start of a line (and thus not in the middle of a comment).
pub fn find_next(&self, bytes: &[u8], chunk_size: &mut usize) -> (usize, usize)
pub fn count_rows(&self, bytes: &[u8], is_eof: bool) -> (usize, usize)
pub fn count(&self, bytes: &[u8]) -> (usize, usize)