Module cloud

Module cloud 

Interface with cloud storage through the object_store crate.

Modules

cloud_writer
concurrency
Adaptive in-flight concurrency controller for cloud IO (Input only).
concurrency_config
credential_provider
dns
options

Structs

CloudLocation
A location on cloud storage, may have wildcards.
CloudOptions
Options to connect to various cloud providers.
CloudRetryConfig
ObjectStoreErrorContext
PolarsObjectStore
Polars wrapper around ObjectStore functionality. This struct is cheaply cloneable.
PolarsObjectStoreError

Enums

AmazonS3ConfigKey
Configuration keys for AmazonS3Builder
AzureConfigKey
Configuration keys for MicrosoftAzureBuilder
CloudConfig
CloudType
GoogleConfigKey
Configuration keys for GoogleCloudStorageBuilder

Statics

USER_AGENT

Traits

ExtObjectStoreBuilder
Trait for external ObjectStore builder (e.g., for HDFS). Unstable.

Functions

build_object_store
Build an ObjectStore based on the URL and passed in url. Return the cloud location and an implementation of the object store.
deregister_object_store_builder
glob
List files with a prefix derived from the pattern.
object_path_from_str
Construct an object_store Path from a string without any encoding/decoding.
register_object_store_builder
Register custom object_store builder for a given cloud scheme. Example: for ‘hdfs://’, the scheme is “hdfs”. Rejects native cloud schemes (e.g. “s3”).

Type Aliases

ObjectStorePath