pub async fn glob(
url: PlRefPath,
cloud_options: Option<&CloudOptions>,
) -> Result<Vec<(String, u64)>, PolarsError>Expand description
List files with a prefix derived from the pattern.
pub async fn glob(
url: PlRefPath,
cloud_options: Option<&CloudOptions>,
) -> Result<Vec<(String, u64)>, PolarsError>List files with a prefix derived from the pattern.