pub enum ExternalCompression {
Uncompressed,
Gzip {
level: Option<u32>,
},
Zstd {
level: Option<u32>,
},
}Expand description
Compression options for file that are expressed externally like CSV and NDJSON. Externally does not mean by an external tool, more that it doesn’t happen internally like it does for Parquet and IPC.
Compared to other formats like IPC and Parquet, compression is external.
Variants
Implementations
Sourceimpl ExternalCompression
impl ExternalCompression
Sourcepub fn file_suffix(self) -> Option<&'static str>
pub fn file_suffix(self) -> Option<&'static str>
Returns the expected file suffix associated with the compression format.
pub fn try_from( value: &str, level: Option<u32>, ) -> Result<ExternalCompression, PolarsError>