GroupsType

Enum GroupsType 

pub enum GroupsType {
    Idx(GroupsIdx),
    Slice {
        groups: Vec<[u32; 2]>,
        overlapping: bool,
        monotonic: bool,
    },
}

Variants



Idx(GroupsIdx)



Slice

Fields

groups: Vec<[u32; 2]>
overlapping: bool

Indicates if the groups may overlap, i.e., at least one index MAY be included in more than one group slice.

monotonic: bool

Indicates if the groups are rolling, i.e. for every consecutive group slice (offset, len), and given start = offset and end = offset + len, then both new_start >= start AND new_end >= end MUST be true.

Implementations

Source

impl GroupsType

pub fn new_slice( groups: Vec<[u32; 2]>, overlapping: bool, monotonic: bool, ) -> GroupsType

pub fn into_idx(self) -> GroupsIdx

pub fn iter(&self) -> GroupsTypeIter<'_>

pub fn sort_by_first_idx(&mut self)

pub fn is_overlapping(&self) -> bool

pub fn is_monotonic(&self) -> bool

pub fn take_group_firsts(self) -> Vec<u32>

pub fn check_lengths(&self, other: &GroupsType) -> Result<(), PolarsError>

Checks if groups are of equal length. The caller is responsible for updating the groups by calling groups() prior to calling this method.

pub unsafe fn take_group_lasts(self) -> Vec<u32>

Safety

This will not do any bounds checks. The caller must ensure all groups have members.

pub fn par_iter(&self) -> GroupsTypeParIter<'_>

pub fn unwrap_idx(&self) -> &GroupsIdx

Get a reference to the GroupsIdx.

Panic

panics if the groups are a slice.

pub fn unwrap_slice(&self) -> &Vec<[u32; 2]>

Get a reference to the GroupsSlice.

Panic

panics if the groups are an idx.

pub fn get(&self, index: usize) -> GroupsIndicator<'_>

pub fn idx_mut(&mut self) -> &mut GroupsIdx

Get a mutable reference to the GroupsIdx.

Panic

panics if the groups are a slice.

pub fn len(&self) -> usize

pub fn is_empty(&self) -> bool

pub fn group_count(&self) -> ChunkedArray<UInt32Type>

pub fn as_list_chunked(&self) -> ChunkedArray<ListType>

pub fn into_sliceable(self) -> GroupPositions

pub fn num_elements(&self) -> usize