pub enum FileProviderType {
Hive(HivePathProvider),
Iceberg(IcebergPathProvider),
Function(PlanCallback<FileProviderArgs, FileProviderReturn>),
}Variants
Hive(HivePathProvider)
Iceberg(IcebergPathProvider)
Function(PlanCallback<FileProviderArgs, FileProviderReturn>)
Implementations
Sourceimpl FileProviderType
impl FileProviderType
Sourcepub fn file_part_prefix_mut(&mut self) -> Option<&mut String>
pub fn file_part_prefix_mut(&mut self) -> Option<&mut String>
Get a mutable reference to the file part prefix for this file provider.
File part prefixes are inserted after the partition prefix, before the file part number.
Returns
Returns None if this file provider does not support attaching file part prefixes.
pub fn get_path_or_file( &self, args: FileProviderArgs, ) -> Result<FileProviderReturn, PolarsError>