pub fn expand_paths(
paths: &[PlPath],
glob: bool,
cloud_options: &mut Option<CloudOptions>,
) -> Result<Arc<[PlPath]>, PolarsError>Expand description
Recursively traverses directories and expands globs if glob is true.
pub fn expand_paths(
paths: &[PlPath],
glob: bool,
cloud_options: &mut Option<CloudOptions>,
) -> Result<Arc<[PlPath]>, PolarsError>Recursively traverses directories and expands globs if glob is true.