ChunkZip

Trait ChunkZip 

pub trait ChunkZip<T>
where T: PolarsDataType,
{ // Required method fn zip_with( &self, mask: &ChunkedArray<BooleanType>, other: &ChunkedArray<T>, ) -> Result<ChunkedArray<T>, PolarsError>; }
Combine two ChunkedArray based on some predicate.

Required Methods

fn zip_with( &self, mask: &ChunkedArray<BooleanType>, other: &ChunkedArray<T>, ) -> Result<ChunkedArray<T>, PolarsError>

Create a new ChunkedArray with values from self where the mask evaluates true and values from other where the mask evaluates false

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl ChunkZip<StructType> for ChunkedArray<StructType>

Available on crate feature dtype-struct only.
Source

impl<T> ChunkZip<T> for ChunkedArray<T>
where <T as PolarsDataType>::Array: for<'a> IfThenElseKernel<Scalar<'a> = <T as PolarsDataType>::Physical<'a>>, T: PolarsDataType<IsStruct = FalseT>, ChunkedArray<T>: ChunkExpandAtIndex<T>,