pub trait IntoGroupsType {
// Provided method
fn group_tuples(
&self,
_multithreaded: bool,
_sorted: bool,
) -> Result<GroupsType, PolarsError> { ... }
}Expand description
Used to create the tuples for a group_by operation.
Provided Methods
Sourcefn group_tuples(
&self,
_multithreaded: bool,
_sorted: bool,
) -> Result<GroupsType, PolarsError>
fn group_tuples( &self, _multithreaded: bool, _sorted: bool, ) -> Result<GroupsType, PolarsError>
Create the tuples need for a group_by operation. * The first value in the tuple is the first index of the group. * The second value in the tuple is the indexes of the groups including the first value.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementors
impl IntoGroupsType for ChunkedArray<BinaryOffsetType>
impl IntoGroupsType for ChunkedArray<BinaryType>
impl IntoGroupsType for ChunkedArray<BooleanType>
impl IntoGroupsType for ChunkedArray<FixedSizeListType>
Available on crate feature
dtype-array only.impl IntoGroupsType for ChunkedArray<ListType>
impl IntoGroupsType for ChunkedArray<StringType>
impl<T> IntoGroupsType for ChunkedArray<ObjectType<T>>where
T: PolarsObject,
Available on crate feature
object only.impl<T> IntoGroupsType for ChunkedArray<T>where
T: PolarsNumericType,
<T as PolarsNumericType>::Native: TotalHash + TotalEq + DirtyHash + ToTotalOrd,
<<T as PolarsNumericType>::Native as ToTotalOrd>::TotalOrdItem: Send + Sync + Copy + Hash + Eq + DirtyHash,
impl<T> IntoGroupsType for Logical<T, <T as PolarsCategoricalType>::PolarsPhysical>where
T: PolarsCategoricalType,
ChunkedArray<<T as PolarsCategoricalType>::PolarsPhysical>: IntoGroupsType,
Available on crate features
dtype-categorical and performant only.